==> haskell-with-utf8-1.1.0.0-126.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-CJYrCkSkcGx5pwtuxqxCdI
key:                  with-utf8-1.1.0.0-CJYrCkSkcGx5pwtuxqxCdI
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  5349c265d8b3af87c7850112d67b0f8f
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.6.6/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/with-utf8-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-CJYrCkSkcGx5pwtuxqxCdI
depends:
    base-4.18.2.1 safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-with-utf8-1.1.0.0-127-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-HB9jgqgnnG0JT7GqSp5V7U
key:                  with-utf8-1.1.0.0-HB9jgqgnnG0JT7GqSp5V7U
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  3f127d7750a8b05c07eb0ab51809b2ae
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.6.6/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/with-utf8-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-HB9jgqgnnG0JT7GqSp5V7U
depends:
    base-4.18.2.1 safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
